@@ -20,7 +20,8 @@ class DDCutilDisplay : public QObject
     Q_OBJECT
 public:
 #ifdef WITH_DDCUTIL
-    DDCutilDisplay(DDCA_Display_Info, DDCA_Display_Handle);
+    DDCutilDisplay(DDCA_Display_Ref);
+    DDCA_IO_Path ioPath() const;
 #endif
     ~DDCutilDisplay();
 
@@ -32,9 +33,10 @@ public:
 
 private:
 #ifdef WITH_DDCUTIL
-    DDCA_Display_Info m_displayInfo;
-    DDCA_Display_Handle m_displayHandle;
+    DDCA_Display_Ref m_displayRef;
+    DDCA_IO_Path m_ioPath;
 #endif
+    QString m_label;
     QReadWriteLock m_lock;
     int m_brightness;
     int m_maxBrightness;
